@@ -1,4 +1,5 @@
 import os
+import re
 import sys
 import traceback
 
@@ -18,6 +19,7 @@ from nashvegas.utils import get_sql_for_new_models
 
 
 sys.path.append("migrations")
+MIGRATION_NAME_RE = re.compile(r"(\d+)(.*)")
 
 
 class MigrationError(Exception):
@@ -52,7 +54,7 @@ class Command(BaseCommand):
             ),
             help="The path to the database migration scripts."))
     help = "Upgrade database."
-
+    
     def _filter_down(self, stop_at=None):
         
         if stop_at is None:
@@ -76,10 +78,11 @@ class Command(BaseCommand):
             
             for script in in_directory:
                 name, ext = os.path.splitext(script)
-                try:
-                    number = int(name.split("_")[0])
-                except ValueError:
-                    raise MigrationError("Invalid migration file prefix (must begin with a number)")
+                match = MIGRATION_NAME_RE.match(name)
+                if match is None:
+                    raise MigrationError("Invalid migration file prefix "
+                                         "(must begin with a number)")
+                number = int(match.group(1))
                 if ext in [".sql", ".py"]:
                     scripts_in_directory.append((number, script))
             
@@ -88,9 +91,9 @@ class Command(BaseCommand):
                     to_execute.append(script)
         except OSError, e:
             print str(e)
-
+        
         return to_execute
-
+    
     def _get_rev(self, fpath):
         """
         Get an SCM verion number. Try svn and git.
@@ -113,7 +116,7 @@ class Command(BaseCommand):
                         rev = tokens[1].strip()
             except:
                 pass
-            
+        
         return rev
     
     def init_nashvegas(self):
@@ -122,7 +125,7 @@ class Command(BaseCommand):
         # dispatcher events.
         for app_name in settings.INSTALLED_APPS:
             try:
-                import_module('.management', app_name)
+                import_module(".management", app_name)
             except ImportError, exc:
                 # This is slightly hackish. We want to ignore ImportErrors
                 # if the "management" module itself is missing -- but we don't
@@ -134,7 +137,7 @@ class Command(BaseCommand):
                 # CPython uses the text "No module named management"
                 # PyPy uses "No module named myproject.myapp.management"
                 msg = exc.args[0]
-                if not msg.startswith('No module named') or 'management' not in msg:
+                if not msg.startswith("No module named") or "management" not in msg:
                     raise
         
         # @@@ make cleaner / check explicitly for model instead of looping over and doing string comparisons
@@ -181,6 +184,7 @@ class Command(BaseCommand):
                     
                     try:
                         cursor.execute(to_execute)
+                        cursor.close()
                     except Exception:
                         sys.stdout.write("failed\n")
                         if show_traceback:
@@ -194,7 +198,7 @@ class Command(BaseCommand):
                             created_models.add(
                                 get_model(
                                     *l.replace("### New Model: ", "").strip().split(".")
-                                ) 
+                                )
                             )
                 elif migration_path.endswith(".py"):
                     sys.stdout.write("Executing %s... " % migration)
@@ -245,6 +249,8 @@ class Command(BaseCommand):
             stop_at = int(self.args[0])
         except ValueError:
             raise CommandError("Invalid --seed migration")
+        except IndexError:
+            raise CommandError("Usage: ./manage.py upgradedb --seed <stop_at>")
         migrations = [os.path.join(self.path, m) for m in self._filter_down(stop_at=stop_at)]
         for migration in migrations:
             m, created = Migration.objects.get_or_create(
@@ -259,7 +265,6 @@ class Command(BaseCommand):
             else:
                 print m.migration_label, "was already applied."
     
-    
     def list_migrations(self):
         migrations = self._filter_down()
         if len(migrations) == 0:
@@ -273,7 +278,7 @@ class Command(BaseCommand):
     def handle(self, *args, **options):
         """
         Upgrades the database.
-
+        
         Executes SQL scripts that haven't already been applied to the
         database.
         """
@@ -289,7 +294,7 @@ class Command(BaseCommand):
         self.db = options.get("database", DEFAULT_DB_ALIAS)
         
         self.init_nashvegas()
-
+        
         if self.do_create:
             self.create_migrations()
         
@@ -301,4 +306,3 @@ class Command(BaseCommand):
         
         if self.do_seed:
             self.seed_migrations()
-
