@@ -9,3 +9,6 @@ class Migration(models.Model):
     date_created = models.DateTimeField(default=datetime.now)
     content = models.TextField()
     scm_version = models.CharField(max_length=50, null=True, blank=True)
+    
+    def __unicode__(self):
+        return unicode("%s [%s]" % (self.migration_label, self.scm_version))
